import bodyParser from 'body-parser';
import fs from 'fs';
import getExt from '../utilities/get-ext.js';

/**
 * Returns a list of raw videos.
 */
const getRaw = (req, res, next) => {
  try {
    fs.readdir(process.env.SRC_RAW, (err, files) => {
      if (err) {
        res
        .status(500)
        .end();
      } else {
        // Read only certain extensions for added security.
        const filtered = files.filter(f => getExt(f) === process.env.EXT_RAW);
        res
        .status(200)
        .send(filtered);
      }
      next();
    });
  } catch (e) {
    console.log(e);
    next();
  }
}

/**
 * Returns a list of decoded videos.
 */
const getDecoded = (req, res, next) => {
  try {
    fs.readdir(process.env.SRC_DECODED, (err, files) => {
      if (err) {
        res
        .status(500)
        .end();
      } else {
        // Read only certain extensions for added security.
        const filtered = files.filter(f => getExt(f) === process.env.EXT_DECODED);
        res
        .status(200)
        .send(filtered);
      }
      next();
    });
  } catch (e) {
    console.log(e);
    next();
  }
}

/**
 * Sets services used in this app.
 */
const setServices = app => {
  app.use(bodyParser.urlencoded({
    extended: true,
  }));
  app.use(bodyParser.json());
  app.get('/api/raw', (req, res, next) => getRaw(req, res, next));
  app.get('/api/decoded', (req, res, next) => getDecoded(req, res, next));
};

export default setServices;
