const webpack = require('webpack');
const path = require('path');
const { CleanWebpackPlugin } = require('clean-webpack-plugin');

const root = path.resolve(__dirname, './');
const src = path.resolve(__dirname, './src');
const dist = path.resolve(__dirname, './dist');

module.exports = {
  mode: 'production',
  name: 'server',
  target: 'node',
  entry: `${src}/index.js`,
  output: {
    path: dist,
    filename: 'live-base.js',
  },
  module: {
    rules: [
      {
        test: /\.(js)$/,
        use: 'babel-loader',
        exclude: /node_modules/,
      },
    ],
  },
  plugins: [
    new CleanWebpackPlugin(),
    // Define globals.
    new webpack.DefinePlugin({
      'process.env.SRC_DECODED': JSON.stringify(process.env.SRC_DECODED || root),
      'process.env.SRC_RAW': JSON.stringify(process.env.SRC_RAW || root),
      'process.env.EXT_DECODED': JSON.stringify(process.env.EXT_DECODED || 'mp4'),
      'process.env.EXT_RAW': JSON.stringify(process.env.EXT_RAW || 'flv'),
    }),
  ],
  node: {
    __dirname: false,
    __filename: false,
  },
}
